"use strict";

function isNativeReflectConstruct() { if (typeof Reflect === "undefined" || !Reflect.construct) return false; if (Reflect.construct.sham) return false; if (typeof Proxy === "function") return true; try { Date.prototype.toString.call(Reflect.construct(Date, [], function () {})); return true; } catch (e) { return false; } }

function _construct(Parent, args, Class) { if (isNativeReflectConstruct()) { _construct = Reflect.construct; } else { _construct = function _construct(Parent, args, Class) { var a = [null]; a.push.apply(a, args); var Constructor = Function.bind.apply(Parent, a); var instance = new Constructor(); if (Class) _setPrototypeOf(instance, Class.prototype); return instance; }; } return _construct.apply(null, arguments); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

/**
 * Class Collapsible
 * @class
 */
var Collapsible =
/*#__PURE__*/
function () {
  /**
   * Construct Collapsible instance
   * @constructor
   * @param {String} element
   * @param {Object} options
   */
  function Collapsible(element, options) {
    _classCallCheck(this, Collapsible);

    this.defaultOptions = {
      animationDelay: 300,
      sidenav: {
        activeClass: true,
        activeWhenOpen: true,
        autoCloseOtherCollapsible: true
      }
    };
    this.el = document.querySelector(element);
    this.el.Collapsible = this;
    this.collapsibleTriggers = document.querySelectorAll('.collapsible-trigger');
    this.initialStart = true;
    this.isActive = this.el.classList.contains('active') ? true : false;
    this.isAnimated = false;
    this.isInSidenav = false;
    this.childIsActive = false;
    this.options = extend(this.defaultOptions, options);

    this._setup();
  }
  /**
   * Setup listeners
   */


  _createClass(Collapsible, [{
    key: "_setup",
    value: function _setup() {
      var _this = this;

      this.collapsibleTriggers.forEach(function (trigger) {
        if (trigger.dataset.target === _this.el.id) {
          trigger.addEventListener('click', function (e) {
            return _this._onClickTrigger(e, _this.el.id);
          });
        }
      });
      this.el.style.transitionDuration = this.options.animationDelay + 'ms';

      this._detectSidenav();

      this._detectChild();

      this.options.sidenav.activeClass ? this._addActiveInSidenav() : '';
      this.isActive ? this.open() : '';
      this.initialStart = false;
    }
    /**
     * Check if collapsible is in sidenav
     */

  }, {
    key: "_detectSidenav",
    value: function _detectSidenav() {
      var elements = [];
      var currElement = this.el;
      elements.push(currElement);

      while (currElement.parentElement) {
        elements.unshift(currElement.parentElement);
        currElement = currElement.parentElement;

        if (currElement.classList.contains('sidenav')) {
          this.isInSidenav = true;
          this.sidenavId = currElement.id;
          break;
        }
      }

      this.sidenavCollapsibles = document.querySelectorAll('#' + this.sidenavId + ' .collapsible');
    }
    /**
     * Check if collapsible have active childs
     */

  }, {
    key: "_detectChild",
    value: function _detectChild() {
      var childrens = this.el.children;
      var _iteratorNormalCompletion = true;
      var _didIteratorError = false;
      var _iteratorError = undefined;

      try {
        for (var _iterator = childrens[Symbol.iterator](), _step; !(_iteratorNormalCompletion = (_step = _iterator.next()).done); _iteratorNormalCompletion = true) {
          var child = _step.value;

          if (child.classList.contains('active')) {
            this.childIsActive = true;
            break;
          }
        }
      } catch (err) {
        _didIteratorError = true;
        _iteratorError = err;
      } finally {
        try {
          if (!_iteratorNormalCompletion && _iterator.return != null) {
            _iterator.return();
          }
        } finally {
          if (_didIteratorError) {
            throw _iteratorError;
          }
        }
      }
    }
    /**
     * Add active class to trigger and collapsible
     */

  }, {
    key: "_addActiveInSidenav",
    value: function _addActiveInSidenav() {
      var _this2 = this;

      if (this.childIsActive && this.isInSidenav) {
        var triggers = document.querySelectorAll('.sidenav .collapsible-trigger');
        triggers.forEach(function (trigger) {
          if (trigger.dataset.target === _this2.el.id) {
            trigger.classList.add('active');
          }
        });
        this.el.classList.add('active');
        this.open();
        this.isActive = true;
      }
    }
    /**
     * Enable / disable active state to trigger when collapsible is in sidenav
     * @param {boolean} state enable or disable
     */

  }, {
    key: "_addActiveToTrigger",
    value: function _addActiveToTrigger(state) {
      var _this3 = this;

      var triggers = document.querySelectorAll('.sidenav .collapsible-trigger');
      triggers.forEach(function (trigger) {
        if (trigger.dataset.target === _this3.el.id) {
          state ? trigger.classList.add('active') : trigger.classList.remove('active');
        }
      });
    }
    /**
     * Auto close others collapsible
     */

  }, {
    key: "_autoCloseOtherCollapsible",
    value: function _autoCloseOtherCollapsible() {
      var _this4 = this;

      if (!this.initialStart && this.isInSidenav) {
        this.sidenavCollapsibles.forEach(function (collapsible) {
          if (collapsible.id !== _this4.el.id) {
            collapsible.Collapsible.close();
          }
        });
      }
    }
    /**
     * Apply overflow hidden and automatically remove
     */

  }, {
    key: "_applyOverflow",
    value: function _applyOverflow() {
      var _this5 = this;

      this.el.style.overflow = 'hidden';
      setTimeout(function () {
        _this5.el.style.overflow = '';
      }, this.options.animationDelay);
    }
    /**
     * Handle click on trigger
     */

  }, {
    key: "_onClickTrigger",
    value: function _onClickTrigger(e, id) {
      e.preventDefault();
      var element = document.querySelector('#' + id);
      var collapsible = element.Collapsible;

      if (collapsible.isAnimated) {
        return;
      }

      if (collapsible.isActive) {
        collapsible.close();
      } else {
        collapsible.open();
      }
    }
    /**
     * Open collapsible
     */

  }, {
    key: "open",
    value: function open() {
      var _this6 = this;

      if (this.isActive) {
        return;
      }

      this.isActive = true;
      this.isAnimated = true;
      this.el.style.display = 'block';

      this._applyOverflow();

      this.el.style.maxHeight = this.el.scrollHeight + 'px';
      this.options.sidenav.activeWhenOpen ? this._addActiveToTrigger(true) : '';
      this.options.sidenav.autoCloseOtherCollapsible ? this._autoCloseOtherCollapsible() : '';
      setTimeout(function () {
        _this6.isAnimated = false;
      }, this.options.animationDelay);
    }
    /**
     * Close collapsible
     */

  }, {
    key: "close",
    value: function close() {
      var _this7 = this;

      if (!this.isActive) {
        return;
      }

      this.isAnimated = true;
      this.el.style.maxHeight = '';

      this._applyOverflow();

      this.options.sidenav.activeWhenOpen ? this._addActiveToTrigger(false) : '';
      setTimeout(function () {
        _this7.el.style.display = '';
        _this7.isAnimated = false;
        _this7.isActive = false;
      }, this.options.animationDelay);
    }
  }]);

  return Collapsible;
}();
/**
 * Class Axentix
 * @class
 */


var Axentix =
/*#__PURE__*/
function () {
  /**
   * Construct Axentix instance
   * @constructor
   * @param {String} component
   * @param {Object} options
   */
  function Axentix(component, options) {
    _classCallCheck(this, Axentix);

    this.component = component[0].toUpperCase() + component.slice(1);
    this.isAll = component === 'all' ? true : false;
    this.options = this.isAll ? {} : options;
    this.instances = [];

    this._init();
  }
  /**
   * Init components
   */


  _createClass(Axentix, [{
    key: "_init",
    value: function _init() {
      var _this8 = this;

      var componentList = {
        Collapsible: document.querySelectorAll('.collapsible:not(.no-axentix-init)'),
        Sidenav: document.querySelectorAll('.sidenav:not(.no-axentix-init)'),
        Modal: document.querySelectorAll('.modal:not(.no-axentix-init)')
      };
      var isInList = componentList.hasOwnProperty(this.component);

      if (isInList) {
        var ids = this._detectIds(componentList[this.component]);

        this._instanciate(ids, this.component);
      } else if (this.isAll) {
        Object.keys(componentList).forEach(function (component) {
          var ids = _this8._detectIds(componentList[component]);

          ids.length > 0 ? _this8._instanciate(ids, component) : '';
        });
      }
    }
    /**
     * Detects all ids
     * @param {NodeListOf<Element>} component
     * @return {Array<String>}
     */

  }, {
    key: "_detectIds",
    value: function _detectIds(component) {
      var idList = [];
      component.forEach(function (el) {
        idList.push('#' + el.id);
      });
      return idList;
    }
    /**
     * Instanciate components
     * @param {Array<String>} ids
     * @param {String} component
     */

  }, {
    key: "_instanciate",
    value: function _instanciate(ids, component) {
      var _this9 = this;

      ids.forEach(function (id) {
        var constructor = window[component];
        var args = [id, _this9.options];

        _this9.instances.push(_construct(constructor, args));
      });
    }
    /**
     * Get instance of element
     * @param {String} element Id of element
     */

  }, {
    key: "getInstance",
    value: function getInstance(element) {
      return this.instances.filter(function (instance) {
        return instance.el.id === element;
      })[0];
    }
    /**
     * Get all instances
     */

  }, {
    key: "getAllInstances",
    value: function getAllInstances() {
      return this.instances;
    }
  }]);

  return Axentix;
}();
/**
 * Detect attribute & state of all inputs
 * @param {NodeListOf<Element>} inputElements
 */


Axentix.detectAllInputs = function (inputElements) {
  inputElements.forEach(function (input) {
    Axentix.detectInput(input);
  });
};
/**
 * Detect attribute & state of an input
 * @param {Element} input
 */


Axentix.detectInput = function (input) {
  var isActive = input.parentElement.classList.contains('active');
  var hasContent = input.value.length > 0 || input.placeholder.length > 0;
  var isFocused = document.activeElement === input;
  var isDisabled = input.hasAttribute('disabled') || input.hasAttribute('readonly');

  if (input.firstInit) {
    Axentix.updateInput(input, isActive, hasContent, isFocused);
    input.firstInit = false;
  } else {
    isDisabled ? '' : Axentix.updateInput(input, isActive, hasContent, isFocused);
  }
};
/**
 * Update input field
 * @param {Element} input
 * @param {boolean} isActive
 * @param {boolean} hasContent
 * @param {boolean} isFocused
 */


Axentix.updateInput = function (input, isActive, hasContent, isFocused) {
  if (!isActive && (hasContent || isFocused)) {
    input.parentElement.classList.add('active');
  } else if (isActive && !(hasContent || isFocused)) {
    input.parentElement.classList.remove('active');
  }

  isFocused ? input.parentElement.classList.add('is-focused') : input.parentElement.classList.remove('is-focused');
};
/**
 * Handle listeners
 * @param {Event} e
 * @param {NodeListOf<Element>} inputElements
 */


Axentix.handleListeners = function (e, inputElements) {
  inputElements.forEach(function (input) {
    input === e.target ? Axentix.detectInput(input) : '';
  });
};
/**
 * Setup forms fields listeners
 * @param {NodeListOf<Element>} inputElements
 */


Axentix.setupFormsListeners = function (inputElements) {
  inputElements.forEach(function (input) {
    input.addEventListener('input', Axentix.detectInput(input));
    input.firstInit = true;
  });
  document.addEventListener('focus', function (e) {
    return Axentix.handleListeners(e, inputElements);
  }, true);
  document.addEventListener('blur', function (e) {
    return Axentix.handleListeners(e, inputElements);
  }, true);
}; // Init


document.addEventListener('DOMContentLoaded', function () {
  var inputElements = document.querySelectorAll('.form-material .form-field:not(.form-default) .form-control');

  if (inputElements.length > 0) {
    Axentix.setupFormsListeners(inputElements);
    Axentix.detectAllInputs(inputElements);
  }
});
/**
 * Class Modal
 * @class
 */

var Modal =
/*#__PURE__*/
function () {
  /**
   * Construct Modal instance
   * @constructor
   * @param {String} element
   * @param {Object} options
   */
  function Modal(element, options) {
    _classCallCheck(this, Modal);

    this.defaultOptions = {
      overlay: true,
      bodyScrolling: false,
      animationDelay: 400
    };
    this.el = document.querySelector(element);
    this.el.Modal = this;
    this.modalTriggers = document.querySelectorAll('.modal-trigger');
    this.isActive = this.el.classList.contains('active') ? true : false;
    this.isAnimated = false;
    this.options = extend(this.defaultOptions, options);

    if (this.options.overlay) {
      this._createOverlay();
    }

    this._setup();

    this.isActive ? this.open() : '';
  }
  /**
   * Setup listeners
   */


  _createClass(Modal, [{
    key: "_setup",
    value: function _setup() {
      var _this10 = this;

      this.modalTriggers.forEach(function (trigger) {
        if (trigger.dataset.target === _this10.el.id) {
          trigger.addEventListener('click', function (e) {
            return _this10._onClickTrigger(e, _this10.el.id);
          });
        }
      });

      if (this.options.overlay) {
        this.overlayElement.addEventListener('click', function (e) {
          return _this10._onClickTrigger(e, _this10.el.id);
        });
      }

      this.el.style.transitionDuration = this.options.animationDelay + 'ms';
    }
    /**
     * Create overlay element
     */

  }, {
    key: "_createOverlay",
    value: function _createOverlay() {
      this.overlayElement = document.createElement('div');
      this.overlayElement.classList.add('modal-overlay');
      this.overlayElement.style.transitionDuration = this.options.animationDelay + 'ms';
      this.overlayElement.dataset.target = this.el.id;
    }
    /**
     * Enable or disable body scroll when option is true
     * @param {boolean} state Enable or disable body scroll
     */

  }, {
    key: "_toggleBodyScroll",
    value: function _toggleBodyScroll(state) {
      if (!this.options.bodyScrolling) {
        state ? document.body.style.overflow = '' : document.body.style.overflow = 'hidden';
      }
    }
    /**
     * Set Z-Index when modal is open
     */

  }, {
    key: "_setZIndex",
    value: function _setZIndex() {
      var totalModals = document.querySelectorAll('.modal.active').length + 1;
      this.options.overlay ? this.overlayElement.style.zIndex = 800 + totalModals * 6 : '';
      this.el.style.zIndex = 800 + totalModals * 10;
    }
    /**
     * Handle click on trigger
     */

  }, {
    key: "_onClickTrigger",
    value: function _onClickTrigger(e, id) {
      e.preventDefault();
      var modal = document.querySelector('#' + id).Modal;

      if (modal.isAnimated) {
        return;
      }

      if (modal.isActive) {
        modal.close();
      } else {
        modal.open();
      }
    }
    /**
     * Open the modal
     */

  }, {
    key: "open",
    value: function open() {
      var _this11 = this;

      if (this.isActive) {
        return;
      }

      this.isActive = true;
      this.isAnimated = true;

      this._setZIndex();

      this.el.style.display = 'block';
      this.overlay(true);

      this._toggleBodyScroll(false);

      setTimeout(function () {
        _this11.el.classList.add('active');
      }, 50);
      setTimeout(function () {
        _this11.isAnimated = false;
      }, this.options.animationDelay);
    }
    /**
     * Close the modal
     */

  }, {
    key: "close",
    value: function close() {
      var _this12 = this;

      if (!this.isActive) {
        return;
      }

      this.isAnimated = true;
      this.el.classList.remove('active');
      this.overlay(false);
      setTimeout(function () {
        _this12.el.style.display = '';
        _this12.isAnimated = false;
        _this12.isActive = false;

        _this12._toggleBodyScroll(true);
      }, this.options.animationDelay);
    }
    /**
     * Manage overlay
     * @param {boolean} state
     */

  }, {
    key: "overlay",
    value: function overlay(state) {
      var _this13 = this;

      if (this.options.overlay) {
        if (state) {
          document.body.appendChild(this.overlayElement);
          setTimeout(function () {
            _this13.overlayElement.classList.add('active');
          }, 50);
        } else {
          this.overlayElement.classList.remove('active');
          setTimeout(function () {
            document.body.removeChild(_this13.overlayElement);
          }, this.options.animationDelay);
        }
      }
    }
  }]);

  return Modal;
}();
/**
 * Class Sidenav
 * @class
 */


var Sidenav =
/*#__PURE__*/
function () {
  /**
   * Construct Sidenav instance
   * @constructor
   * @param {String} element
   * @param {Object} options
   */
  function Sidenav(element, options) {
    _classCallCheck(this, Sidenav);

    this.defaultOptions = {
      overlay: true,
      bodyScrolling: false,
      animationDelay: 300
    };
    this.el = document.querySelector(element);
    this.el.Sidenav = this;
    this.sidenavTriggers = document.querySelectorAll('.sidenav-trigger');
    this.isActive = false;
    this.isFixed = this.el.classList.contains('fixed');
    this.isLarge = this.el.classList.contains('large');
    this.options = extend(this.defaultOptions, options);

    this._setup();
  }
  /**
   * Setup listeners
   */


  _createClass(Sidenav, [{
    key: "_setup",
    value: function _setup() {
      var _this14 = this;

      this.sidenavTriggers.forEach(function (trigger) {
        if (trigger.dataset.target === _this14.el.id) {
          trigger.addEventListener('click', function (e) {
            return _this14._onClickTrigger(e, _this14.el.id);
          });
        }
      });

      if (this.options.overlay) {
        this._createOverlay();

        this.overlayElement.addEventListener('click', function (e) {
          return _this14._onClickTrigger(e, _this14.el.id);
        });
      }

      this.el.classList.contains('large') ? document.body.classList.add('sidenav-large') : '';
      this.el.classList.contains('right-aligned') ? this._handleRightSide() : '';
      this.el.style.transitionDuration = this.options.animationDelay + 'ms';
    }
    /**
     * Create overlay element
     */

  }, {
    key: "_createOverlay",
    value: function _createOverlay() {
      this.overlayElement = document.createElement('div');
      this.overlayElement.classList.add('sidenav-overlay');
      this.overlayElement.dataset.target = this.el.id;
    }
  }, {
    key: "_handleRightSide",
    value: function _handleRightSide() {
      document.body.classList.add('sidenav-right');
    }
    /**
     * Enable or disable body scroll when option is true
     * @param {boolean} state Enable or disable body scroll
     */

  }, {
    key: "_toggleBodyScroll",
    value: function _toggleBodyScroll(state) {
      if (!this.options.bodyScrolling) {
        state ? document.body.style.overflow = '' : document.body.style.overflow = 'hidden';
      }
    }
    /**
     * Handle click on trigger
     */

  }, {
    key: "_onClickTrigger",
    value: function _onClickTrigger(e, id) {
      e.preventDefault();
      var sidenav = document.querySelector('#' + id).Sidenav;

      if (sidenav.isFixed && window.innerWidth >= 960) {
        return;
      }

      if (sidenav.isActive) {
        sidenav.close();
      } else {
        sidenav.open();
      }
    }
    /**
     * Open sidenav
     */

  }, {
    key: "open",
    value: function open() {
      if (this.isActive) {
        return;
      }

      this.isActive = true;
      this.el.classList.add('active');
      this.overlay(true);

      this._toggleBodyScroll(false);
    }
    /**
     * Close sidenav
     */

  }, {
    key: "close",
    value: function close() {
      var _this15 = this;

      if (!this.isActive) {
        return;
      }

      this.el.classList.remove('active');
      this.overlay(false);
      setTimeout(function () {
        _this15._toggleBodyScroll(true);

        _this15.isActive = false;
      }, this.options.animationDelay);
    }
    /**
     * Manage overlay
     * @param {boolean} state
     */

  }, {
    key: "overlay",
    value: function overlay(state) {
      if (this.options.overlay) {
        state ? document.body.appendChild(this.overlayElement) : document.body.removeChild(this.overlayElement);
      }
    }
  }]);

  return Sidenav;
}(); // By https://gomakethings.com/vanilla-javascript-version-of-jquery-extend/ | MIT License
// Pass in the objects to merge as arguments.
// For a deep extend, set the first argument to `true`.


function extend() {
  var extended = {};
  var deep = false;
  var i = 0;
  var length = arguments.length;

  if (Object.prototype.toString.call(arguments[0]) === '[object Boolean]') {
    deep = arguments[0];
    i++;
  }

  var merge = function merge(obj) {
    for (var prop in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, prop)) {
        if (deep && Object.prototype.toString.call(obj[prop]) === '[object Object]') {
          extended[prop] = extend(true, extended[prop], obj[prop]);
        } else {
          extended[prop] = obj[prop];
        }
      }
    }
  };

  for (; i < length; i++) {
    var obj = arguments[i];
    merge(obj);
  }

  return extended;
}